@@ -1,6 +1,6 @@
 # check_perl_modules.pl - This script checks installed and required Perl modules
 # It also does the required installations
-# RCS Identication ; $Revision: 1.47.2.1 $ ; $Date: 2006/06/08 12:53:26 $ 
+# RCS Identication ; $Revision: 1.47.2.2 $ ; $Date: 2006/11/16 09:47:33 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -194,7 +194,7 @@ sub install_module {
     my $answer = <STDIN>; chomp $answer;
     $answer ||= $default;
     next unless ($answer =~ /^y$/i);
-  CPAN::Shell->conf('inactivity_timeout', 4);
+    $CPAN::Config->{'inactivity_timeout'} = 4;
     CPAN::Shell->install($module);
 
     ## Restore lang
