@@ -1,5 +1,5 @@
 /* boucequeue.c - This program does the non-delivery deports spooling
-  RCS Identication ; $Revision: 1.4.2.1 $ ; $Date: 2005/01/27 08:54:02 $ 
+  RCS Identication ; $Revision: 1.7 $ ; $Date: 2006/03/21 09:59:04 $ 
 
   Sympa - SYsteme de Multi-Postage Automatique
   Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -39,11 +39,11 @@ static int      i, fd;
 # define CONFIG		"/etc/sympa.conf"
 #endif
 
-unsigned char *
+char *
 readconf(char *file)
 {
    FILE			*f;
-   unsigned char	buf[16384], *p, *r, *s;
+   char	buf[16384], *p, *r, *s;
 
    r = NULL;
    if ((f = fopen(file, "r")) != NULL) {
@@ -51,7 +51,7 @@ readconf(char *file)
 	/* Search for the configword "queuebounce" and a whitespace after it */
 	if (strncmp(buf, "queuebounce", 11) == 0 && isspace(buf[11])) {
             /* Strip the ending \n */
-            if ((p = (unsigned char *)strrchr((char *)buf, '\n')) != NULL)
+            if ((p = strrchr((char *)buf, '\n')) != NULL)
                *p = '\0';
             p = buf + 11;
             while (*p && isspace(*p)) p++;
@@ -82,8 +82,8 @@ readconf(char *file)
 int
 main(int argn, char **argv)
 {
-   unsigned char	*bouncedir;
-   unsigned char        *listname;
+   char	*bouncedir;
+   char        *listname;
    unsigned int		priority;
    int			firstfrom = 0;
 
