@@ -1,5 +1,5 @@
 # mail.pm - This module includes mail sending functions and does the smtp job.
-# RCS Identication ; $Revision: 1.35 $ ; $Date: 2006/03/08 15:17:23 $ 
+# RCS Identication ; $Revision: 1.35.2.1 $ ; $Date: 2007/01/22 15:13:33 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -39,7 +39,7 @@ require 'tools.pl';
 #use strict;
 
 ## RCS identification.
-#my $id = '@(#)$Id: mail.pm,v 1.35 2006/03/08 15:17:23 sympa-authors Exp $';
+#my $id = '@(#)$Id: mail.pm,v 1.35.2.1 2007/01/22 15:13:33 olivier.salaun Exp $';
 
 my $opensmtp = 0;
 my $fh = 'fh0000000000';	## File handle for the stream.
@@ -216,7 +216,10 @@ sub mail_file {
     } elsif ($data->{'list'}) {
 	$listname = $data->{'list'};
     }
-       
+     
+    ## Set it in case it was not set
+    $data->{'return_path'} ||= &Conf::get_robot_conf($robot, 'request');
+  
     ## SENDING
     if (ref($rcpt)) {
 	unless (defined &sending($message,$rcpt,$data->{'return_path'},$robot,$listname,$sign_mode)) {
@@ -501,7 +504,7 @@ sub sending {
     my $sympa_file;
     my $fh;
     my $signed_msg; # if signing
-    
+
  
     ## FILE HANDLER
     ## Don't fork if used by a CGI (FastCGI problem)
