@@ -1,5 +1,5 @@
 # bounce-lib.pl - This module includes functions for analysing non-delivery reports
-# RCS Identication ; $Revision: 1.7 $ ; $Date: 2002/08/19 08:48:58 $ 
+# RCS Identication ; $Revision: 1.8.2.1 $ ; $Date: 2006/05/02 14:13:16 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -76,8 +76,12 @@ sub rfc1891 {
 		    $status = $1;
 		}
 		
-		if (/^Final-Recipient:\s*rfc822\s*;\s*(.*)$/mi) {
+		if (/^Original-Recipient:\s*rfc822\s*;\s*(.*)$/mi ||
+		    /^Final-Recipient:\s*rfc822\s*;\s*(.*)$/mi) {
 		    $recipient = $1;
+		    if ($recipient =~ /\@.+:(.+)$/) {
+			$recipient = $1;
+		    }
 		    $recipient =~ s/^<(.*)>$/$1/;
 		    $recipient =~ y/[A-Z]/[a-z]/;
 		}
