@@ -1,5 +1,5 @@
 # cookielib.pm - This module includes functions managing HTTP cookies in Sympa
-# RCS Identication ; $Revision: 1.28 $ ; $Date: 2003/10/31 08:00:58 $ 
+# RCS Identication ; $Revision: 1.30 $ ; $Date: 2005/08/17 14:55:01 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -96,6 +96,24 @@ sub check_lang_cookie {
     return undef;
 }
 
+## Check cookie for expert_page mode in the shared
+sub check_expertpage_cookie {
+    my $http_cookie = shift;
+    
+    my %cookies = parse CGI::Cookie($http_cookie);
+    
+    ## Scan parameters
+    foreach (sort keys %cookies) {
+	my $cookie = $cookies{$_};
+	
+	next unless ($cookie->name eq 'sympaexpertpage');
+
+	return $cookie->value;
+    }
+
+    return undef;
+}
+
 ## Set user $email cookie, ckecksum use $secret, expire=(now|session|#sec) domain=(localhost|<a domain>)
 sub set_cookie {
     my ($email, $secret, $http_domain, $expires, $auth) = @_ ;
@@ -317,11 +335,44 @@ sub get_which_cookie {
     return undef;
 }
 
+## Set cookie for expert_page mode in the shared
+sub set_expertpage_cookie {
+    my ($put,$domain) = @_;
+    
+    if ($domain eq 'localhost') {
+	$domain="";
+    }
+    
+    my $expire;
+    if ($put == 1) {
+	$expire = '+1y';
+    } else {
+	$expire = '-10y';
+    }
+    
+    my $cookie = new CGI::Cookie (-name    => 'sympaexpertpage',
+				  -value   => '1',
+				  -expires => $expire,
+				  -domain  => $domain,
+				  -path    => '/'
+				  );
+    
+    ## Send cookie to the client
+    printf "Set-Cookie:  %s\n", $cookie->as_string;
+    
+    return 1;
+}
+
 ## Set cookie for accessing web archives
 sub set_which_cookie {
     my $domain = shift ;
     my @which = @_;
 
+    my @listnames;
+    foreach my $list (@which) {
+	push @listnames, $list->{'name'};
+    }
+
     my $commawhich = join ',', @which;
     
     if ($domain eq 'localhost') {
