@@ -1,5 +1,5 @@
 # wwslib.pm - This module includes functions used by wwsympa.fcgi
-# RCS Identication ; $Revision: 1.53 $ ; $Date: 2006/01/27 14:54:23 $ 
+# RCS Identication ; $Revision: 1.53.2.1 $ ; $Date: 2006/12/21 09:09:20 $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -309,7 +309,7 @@ sub ciphersaber_installed {
 sub crypt_passwd {
     my $inpasswd = shift ;
 
-    unless (define($cipher)){
+    unless (defined($cipher)){
 	$cipher = ciphersaber_installed();
     }
     return $inpasswd if ($cipher eq 'no_cipher') ;
@@ -323,7 +323,7 @@ sub decrypt_passwd {
     return $inpasswd unless ($inpasswd =~ /^crypt\.(.*)$/) ;
     $inpasswd = $1;
 
-    unless (define($cipher)){
+    unless (defined($cipher)){
 	$cipher = ciphersaber_installed();
     }
     if ($cipher eq 'no_cipher') {
